# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/virtualcluster/v1/virtualcluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/virtualcluster/v1/virtualcluster.proto',
  package='github.com.metaprov.modelaapi.services.virtualcluster.v1',
  syntax='proto3',
  serialized_options=b'Z8github.com/metaprov/modelaapi/services/virtualcluster/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nMgithub.com/metaprov/modelaapi/services/virtualcluster/v1/virtualcluster.proto\x12\x38github.com.metaprov.modelaapi.services.virtualcluster.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xf2\x01\n\x1aListVirtualClustersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x86\x01\n\x11virtualclusterels\x18\x03 \x03(\x0b\x32k.github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest.VirtualclusterelsEntry\x1a\x38\n\x16VirtualclusterelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x1bListVirtualClustersResponse\x12X\n\x05items\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualClusterList\"\x18\n\x16VirtualClusterResponse\"r\n\x1b\x43reateVirtualClusterRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"\x1e\n\x1c\x43reateVirtualClusterResponse\"r\n\x1bUpdateVirtualClusterRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"\x1e\n\x1cUpdateVirtualClusterResponse\";\n\x18GetVirtualClusterRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"~\n\x19GetVirtualClusterResponse\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\x12\x0c\n\x04yaml\x18\x02 \x01(\t\">\n\x1b\x44\x65leteVirtualClusterRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteVirtualClusterResponse2\xa7\t\n\x15VirtualClusterService\x12\xe3\x01\n\x13ListVirtualClusters\x12T.github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest\x1aU.github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/virtualclusters\x12\xe5\x01\n\x14\x43reateVirtualCluster\x12U.github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterRequest\x1aV.github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/virtualclusters:\x01*\x12\xe4\x01\n\x11GetVirtualCluster\x12R.github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterRequest\x1aS.github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/virtualclusters/{name}\x12\xec\x01\n\x14UpdateVirtualCluster\x12U.github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterRequest\x1aV.github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterResponse\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/v1/virtualclusters/{name}:\x01*\x12\xe9\x01\n\x14\x44\x65leteVirtualCluster\x12U.github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterRequest\x1aV.github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterResponse\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/virtualclusters/{name}B:Z8github.com/metaprov/modelaapi/services/virtualcluster/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERELSENTRY = _descriptor.Descriptor(
  name='VirtualclusterelsEntry',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest.VirtualclusterelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest.VirtualclusterelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest.VirtualclusterelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=490,
  serialized_end=546,
)

_LISTVIRTUALCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListVirtualClustersRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtualclusterels', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest.virtualclusterels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=546,
)


_LISTVIRTUALCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListVirtualClustersResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=667,
)


_VIRTUALCLUSTERRESPONSE = _descriptor.Descriptor(
  name='VirtualClusterResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.VirtualClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=693,
)


_CREATEVIRTUALCLUSTERREQUEST = _descriptor.Descriptor(
  name='CreateVirtualClusterRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=695,
  serialized_end=809,
)


_CREATEVIRTUALCLUSTERRESPONSE = _descriptor.Descriptor(
  name='CreateVirtualClusterResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=841,
)


_UPDATEVIRTUALCLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateVirtualClusterRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=957,
)


_UPDATEVIRTUALCLUSTERRESPONSE = _descriptor.Descriptor(
  name='UpdateVirtualClusterResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=989,
)


_GETVIRTUALCLUSTERREQUEST = _descriptor.Descriptor(
  name='GetVirtualClusterRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=991,
  serialized_end=1050,
)


_GETVIRTUALCLUSTERRESPONSE = _descriptor.Descriptor(
  name='GetVirtualClusterResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1178,
)


_DELETEVIRTUALCLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteVirtualClusterRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1242,
)


_DELETEVIRTUALCLUSTERRESPONSE = _descriptor.Descriptor(
  name='DeleteVirtualClusterResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1244,
  serialized_end=1274,
)

_LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERELSENTRY.containing_type = _LISTVIRTUALCLUSTERSREQUEST
_LISTVIRTUALCLUSTERSREQUEST.fields_by_name['virtualclusterels'].message_type = _LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERELSENTRY
_LISTVIRTUALCLUSTERSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTERLIST
_CREATEVIRTUALCLUSTERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTER
_UPDATEVIRTUALCLUSTERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTER
_GETVIRTUALCLUSTERRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTER
DESCRIPTOR.message_types_by_name['ListVirtualClustersRequest'] = _LISTVIRTUALCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualClustersResponse'] = _LISTVIRTUALCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['VirtualClusterResponse'] = _VIRTUALCLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['CreateVirtualClusterRequest'] = _CREATEVIRTUALCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateVirtualClusterResponse'] = _CREATEVIRTUALCLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['UpdateVirtualClusterRequest'] = _UPDATEVIRTUALCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateVirtualClusterResponse'] = _UPDATEVIRTUALCLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['GetVirtualClusterRequest'] = _GETVIRTUALCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['GetVirtualClusterResponse'] = _GETVIRTUALCLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['DeleteVirtualClusterRequest'] = _DELETEVIRTUALCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteVirtualClusterResponse'] = _DELETEVIRTUALCLUSTERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListVirtualClustersRequest = _reflection.GeneratedProtocolMessageType('ListVirtualClustersRequest', (_message.Message,), {

  'VirtualclusterelsEntry' : _reflection.GeneratedProtocolMessageType('VirtualclusterelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest.VirtualclusterelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTVIRTUALCLUSTERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersRequest)
  })
_sym_db.RegisterMessage(ListVirtualClustersRequest)
_sym_db.RegisterMessage(ListVirtualClustersRequest.VirtualclusterelsEntry)

ListVirtualClustersResponse = _reflection.GeneratedProtocolMessageType('ListVirtualClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALCLUSTERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.ListVirtualClustersResponse)
  })
_sym_db.RegisterMessage(ListVirtualClustersResponse)

VirtualClusterResponse = _reflection.GeneratedProtocolMessageType('VirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.VirtualClusterResponse)
  })
_sym_db.RegisterMessage(VirtualClusterResponse)

CreateVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterRequest)
  })
_sym_db.RegisterMessage(CreateVirtualClusterRequest)

CreateVirtualClusterResponse = _reflection.GeneratedProtocolMessageType('CreateVirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.CreateVirtualClusterResponse)
  })
_sym_db.RegisterMessage(CreateVirtualClusterResponse)

UpdateVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualClusterRequest)

UpdateVirtualClusterResponse = _reflection.GeneratedProtocolMessageType('UpdateVirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.UpdateVirtualClusterResponse)
  })
_sym_db.RegisterMessage(UpdateVirtualClusterResponse)

GetVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('GetVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterRequest)
  })
_sym_db.RegisterMessage(GetVirtualClusterRequest)

GetVirtualClusterResponse = _reflection.GeneratedProtocolMessageType('GetVirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.GetVirtualClusterResponse)
  })
_sym_db.RegisterMessage(GetVirtualClusterResponse)

DeleteVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualClusterRequest)

DeleteVirtualClusterResponse = _reflection.GeneratedProtocolMessageType('DeleteVirtualClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALCLUSTERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualcluster.v1.virtualcluster_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualcluster.v1.DeleteVirtualClusterResponse)
  })
_sym_db.RegisterMessage(DeleteVirtualClusterResponse)


DESCRIPTOR._options = None
_LISTVIRTUALCLUSTERSREQUEST_VIRTUALCLUSTERELSENTRY._options = None

_VIRTUALCLUSTERSERVICE = _descriptor.ServiceDescriptor(
  name='VirtualClusterService',
  full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.VirtualClusterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1277,
  serialized_end=2468,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListVirtualClusters',
    full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.VirtualClusterService.ListVirtualClusters',
    index=0,
    containing_service=None,
    input_type=_LISTVIRTUALCLUSTERSREQUEST,
    output_type=_LISTVIRTUALCLUSTERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/api/v1/virtualclusters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateVirtualCluster',
    full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.VirtualClusterService.CreateVirtualCluster',
    index=1,
    containing_service=None,
    input_type=_CREATEVIRTUALCLUSTERREQUEST,
    output_type=_CREATEVIRTUALCLUSTERRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\"\023/v1/virtualclusters:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVirtualCluster',
    full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.VirtualClusterService.GetVirtualCluster',
    index=2,
    containing_service=None,
    input_type=_GETVIRTUALCLUSTERREQUEST,
    output_type=_GETVIRTUALCLUSTERRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/api/v1/virtualclusters/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateVirtualCluster',
    full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.VirtualClusterService.UpdateVirtualCluster',
    index=3,
    containing_service=None,
    input_type=_UPDATEVIRTUALCLUSTERREQUEST,
    output_type=_UPDATEVIRTUALCLUSTERRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\032\032/v1/virtualclusters/{name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteVirtualCluster',
    full_name='github.com.metaprov.modelaapi.services.virtualcluster.v1.VirtualClusterService.DeleteVirtualCluster',
    index=4,
    containing_service=None,
    input_type=_DELETEVIRTUALCLUSTERREQUEST,
    output_type=_DELETEVIRTUALCLUSTERRESPONSE,
    serialized_options=b'\202\323\344\223\002\034*\032/v1/virtualclusters/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALCLUSTERSERVICE)

DESCRIPTOR.services_by_name['VirtualClusterService'] = _VIRTUALCLUSTERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/notifier/v1/notifier.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/notifier/v1/notifier.proto',
  package='github.com.metaprov.modelaapi.services.notifier.v1',
  syntax='proto3',
  serialized_options=b'Z2github.com/metaprov/modelaapi/services/notifier/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAgithub.com/metaprov/modelaapi/services/notifier/v1/notifier.proto\x12\x32github.com.metaprov.modelaapi.services.notifier.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xbe\x01\n\x14ListNotifiersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x03 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x15ListNotifiersResponse\x12R\n\x05items\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.NotifierList\"\x12\n\x10NotifierResponse\"f\n\x15\x43reateNotifierRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x18\n\x16\x43reateNotifierResponse\"f\n\x15UpdateNotifierRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x18\n\x16UpdateNotifierResponse\"5\n\x12GetNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x13GetNotifierResponse\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"8\n\x15\x44\x65leteNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteNotifierResponse2\xbb\x08\n\x0fNotifierService\x12\xc5\x01\n\rListNotifiers\x12H.github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest\x1aI.github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1alpha1/notifiers\x12\xcb\x01\n\x0e\x43reateNotifier\x12I.github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierRequest\x1aJ.github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1alpha1/notifiers:\x01*\x12\xc6\x01\n\x0bGetNotifier\x12\x46.github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierRequest\x1aG.github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1alpha1/notifiers/{name}\x12\xe4\x01\n\x0eUpdateNotifier\x12I.github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierRequest\x1aJ.github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierResponse\";\x82\xd3\xe4\x93\x02\x35\x1a\x30/api/v1alpha1/notifiers/{notifier.metadata.name}:\x01*\x12\xe1\x01\n\x0e\x44\x65leteNotifier\x12I.github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierRequest\x1aJ.github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierResponse\"8\x82\xd3\xe4\x93\x02\x32*0/api/v1alpha1/notifiers/{notifier.metadata.name}B4Z2github.com/metaprov/modelaapi/services/notifier/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTNOTIFIERSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=476,
)

_LISTNOTIFIERSREQUEST = _descriptor.Descriptor(
  name='ListNotifiersRequest',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTNOTIFIERSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=476,
)


_LISTNOTIFIERSRESPONSE = _descriptor.Descriptor(
  name='ListNotifiersResponse',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=585,
)


_NOTIFIERRESPONSE = _descriptor.Descriptor(
  name='NotifierResponse',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.NotifierResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=587,
  serialized_end=605,
)


_CREATENOTIFIERREQUEST = _descriptor.Descriptor(
  name='CreateNotifierRequest',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=709,
)


_CREATENOTIFIERRESPONSE = _descriptor.Descriptor(
  name='CreateNotifierResponse',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=735,
)


_UPDATENOTIFIERREQUEST = _descriptor.Descriptor(
  name='UpdateNotifierRequest',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=737,
  serialized_end=839,
)


_UPDATENOTIFIERRESPONSE = _descriptor.Descriptor(
  name='UpdateNotifierResponse',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=865,
)


_GETNOTIFIERREQUEST = _descriptor.Descriptor(
  name='GetNotifierRequest',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=867,
  serialized_end=920,
)


_GETNOTIFIERRESPONSE = _descriptor.Descriptor(
  name='GetNotifierResponse',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=1036,
)


_DELETENOTIFIERREQUEST = _descriptor.Descriptor(
  name='DeleteNotifierRequest',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1094,
)


_DELETENOTIFIERRESPONSE = _descriptor.Descriptor(
  name='DeleteNotifierResponse',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1120,
)

_LISTNOTIFIERSREQUEST_LABELSENTRY.containing_type = _LISTNOTIFIERSREQUEST
_LISTNOTIFIERSREQUEST.fields_by_name['labels'].message_type = _LISTNOTIFIERSREQUEST_LABELSENTRY
_LISTNOTIFIERSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIERLIST
_CREATENOTIFIERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIER
_UPDATENOTIFIERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIER
_GETNOTIFIERRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIER
DESCRIPTOR.message_types_by_name['ListNotifiersRequest'] = _LISTNOTIFIERSREQUEST
DESCRIPTOR.message_types_by_name['ListNotifiersResponse'] = _LISTNOTIFIERSRESPONSE
DESCRIPTOR.message_types_by_name['NotifierResponse'] = _NOTIFIERRESPONSE
DESCRIPTOR.message_types_by_name['CreateNotifierRequest'] = _CREATENOTIFIERREQUEST
DESCRIPTOR.message_types_by_name['CreateNotifierResponse'] = _CREATENOTIFIERRESPONSE
DESCRIPTOR.message_types_by_name['UpdateNotifierRequest'] = _UPDATENOTIFIERREQUEST
DESCRIPTOR.message_types_by_name['UpdateNotifierResponse'] = _UPDATENOTIFIERRESPONSE
DESCRIPTOR.message_types_by_name['GetNotifierRequest'] = _GETNOTIFIERREQUEST
DESCRIPTOR.message_types_by_name['GetNotifierResponse'] = _GETNOTIFIERRESPONSE
DESCRIPTOR.message_types_by_name['DeleteNotifierRequest'] = _DELETENOTIFIERREQUEST
DESCRIPTOR.message_types_by_name['DeleteNotifierResponse'] = _DELETENOTIFIERRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListNotifiersRequest = _reflection.GeneratedProtocolMessageType('ListNotifiersRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTNOTIFIERSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTNOTIFIERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersRequest)
  })
_sym_db.RegisterMessage(ListNotifiersRequest)
_sym_db.RegisterMessage(ListNotifiersRequest.LabelsEntry)

ListNotifiersResponse = _reflection.GeneratedProtocolMessageType('ListNotifiersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTIFIERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.ListNotifiersResponse)
  })
_sym_db.RegisterMessage(ListNotifiersResponse)

NotifierResponse = _reflection.GeneratedProtocolMessageType('NotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.NotifierResponse)
  })
_sym_db.RegisterMessage(NotifierResponse)

CreateNotifierRequest = _reflection.GeneratedProtocolMessageType('CreateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierRequest)
  })
_sym_db.RegisterMessage(CreateNotifierRequest)

CreateNotifierResponse = _reflection.GeneratedProtocolMessageType('CreateNotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.CreateNotifierResponse)
  })
_sym_db.RegisterMessage(CreateNotifierResponse)

UpdateNotifierRequest = _reflection.GeneratedProtocolMessageType('UpdateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierRequest)
  })
_sym_db.RegisterMessage(UpdateNotifierRequest)

UpdateNotifierResponse = _reflection.GeneratedProtocolMessageType('UpdateNotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.UpdateNotifierResponse)
  })
_sym_db.RegisterMessage(UpdateNotifierResponse)

GetNotifierRequest = _reflection.GeneratedProtocolMessageType('GetNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierRequest)
  })
_sym_db.RegisterMessage(GetNotifierRequest)

GetNotifierResponse = _reflection.GeneratedProtocolMessageType('GetNotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.GetNotifierResponse)
  })
_sym_db.RegisterMessage(GetNotifierResponse)

DeleteNotifierRequest = _reflection.GeneratedProtocolMessageType('DeleteNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierRequest)
  })
_sym_db.RegisterMessage(DeleteNotifierRequest)

DeleteNotifierResponse = _reflection.GeneratedProtocolMessageType('DeleteNotifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFIERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notifier.v1.notifier_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notifier.v1.DeleteNotifierResponse)
  })
_sym_db.RegisterMessage(DeleteNotifierResponse)


DESCRIPTOR._options = None
_LISTNOTIFIERSREQUEST_LABELSENTRY._options = None

_NOTIFIERSERVICE = _descriptor.ServiceDescriptor(
  name='NotifierService',
  full_name='github.com.metaprov.modelaapi.services.notifier.v1.NotifierService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1123,
  serialized_end=2206,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListNotifiers',
    full_name='github.com.metaprov.modelaapi.services.notifier.v1.NotifierService.ListNotifiers',
    index=0,
    containing_service=None,
    input_type=_LISTNOTIFIERSREQUEST,
    output_type=_LISTNOTIFIERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/api/v1alpha1/notifiers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNotifier',
    full_name='github.com.metaprov.modelaapi.services.notifier.v1.NotifierService.CreateNotifier',
    index=1,
    containing_service=None,
    input_type=_CREATENOTIFIERREQUEST,
    output_type=_CREATENOTIFIERRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\027/api/v1alpha1/notifiers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNotifier',
    full_name='github.com.metaprov.modelaapi.services.notifier.v1.NotifierService.GetNotifier',
    index=2,
    containing_service=None,
    input_type=_GETNOTIFIERREQUEST,
    output_type=_GETNOTIFIERRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/api/v1alpha1/notifiers/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNotifier',
    full_name='github.com.metaprov.modelaapi.services.notifier.v1.NotifierService.UpdateNotifier',
    index=3,
    containing_service=None,
    input_type=_UPDATENOTIFIERREQUEST,
    output_type=_UPDATENOTIFIERRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0320/api/v1alpha1/notifiers/{notifier.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteNotifier',
    full_name='github.com.metaprov.modelaapi.services.notifier.v1.NotifierService.DeleteNotifier',
    index=4,
    containing_service=None,
    input_type=_DELETENOTIFIERREQUEST,
    output_type=_DELETENOTIFIERRESPONSE,
    serialized_options=b'\202\323\344\223\0022*0/api/v1alpha1/notifiers/{notifier.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NOTIFIERSERVICE)

DESCRIPTOR.services_by_name['NotifierService'] = _NOTIFIERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/postmortem/v1/postmortem.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/postmortem/v1/postmortem.proto',
  package='github.com.metaprov.modelaapi.services.postmortem.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/postmortem/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/postmortem/v1/postmortem.proto\x12\x34github.com.metaprov.modelaapi.services.postmortem.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\"\xc4\x01\n\x16ListPostMortemsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x03 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x17ListPostMortemsResponse\x12S\n\x05items\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemList\"i\n\x17\x43reatePostMortemRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x1a\n\x18\x43reatePostMortemResponse\"i\n\x17UpdatePostMortemRequest\x12N\n\x04item\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x1a\n\x18UpdatePostMortemResponse\"7\n\x14GetPostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x15GetPostMortemResponse\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65letePostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65letePostMortemResponse2\xd5\x08\n\x11PostMortemService\x12\xc7\x01\n\x0fListPostMortems\x12L.github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest\x1aM.github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/postmortems\x12\xcd\x01\n\x10\x43reatePostMortem\x12M.github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest\x1aN.github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/postmortems:\x01*\x12\xc8\x01\n\rGetPostMortem\x12J.github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest\x1aK.github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/postmortems/{name}\x12\xe8\x01\n\x10UpdatePostMortem\x12M.github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest\x1aN.github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/postmortems/{postmortem.metadata.name}:\x01*\x12\xef\x01\n\x10\x44\x65letePostMortem\x12M.github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest\x1aN.github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemResponse\"<\x82\xd3\xe4\x93\x02\x36*4/api/v1alpha1/postmortems/{postmortem.metadata.name}B6Z4github.com/metaprov/modelaapi/services/postmortem/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTPOSTMORTEMSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=424,
)

_LISTPOSTMORTEMSREQUEST = _descriptor.Descriptor(
  name='ListPostMortemsRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPOSTMORTEMSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=424,
)


_LISTPOSTMORTEMSRESPONSE = _descriptor.Descriptor(
  name='ListPostMortemsResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=536,
)


_CREATEPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='CreatePostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=643,
)


_CREATEPOSTMORTEMRESPONSE = _descriptor.Descriptor(
  name='CreatePostMortemResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=671,
)


_UPDATEPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='UpdatePostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest.item', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=673,
  serialized_end=778,
)


_UPDATEPOSTMORTEMRESPONSE = _descriptor.Descriptor(
  name='UpdatePostMortemResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=806,
)


_GETPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='GetPostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=808,
  serialized_end=863,
)


_GETPOSTMORTEMRESPONSE = _descriptor.Descriptor(
  name='GetPostMortemResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=865,
  serialized_end=982,
)


_DELETEPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='DeletePostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1042,
)


_DELETEPOSTMORTEMRESPONSE = _descriptor.Descriptor(
  name='DeletePostMortemResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1070,
)

_LISTPOSTMORTEMSREQUEST_LABELSENTRY.containing_type = _LISTPOSTMORTEMSREQUEST
_LISTPOSTMORTEMSREQUEST.fields_by_name['labels'].message_type = _LISTPOSTMORTEMSREQUEST_LABELSENTRY
_LISTPOSTMORTEMSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEMLIST
_CREATEPOSTMORTEMREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM
_UPDATEPOSTMORTEMREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM
_GETPOSTMORTEMRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM
DESCRIPTOR.message_types_by_name['ListPostMortemsRequest'] = _LISTPOSTMORTEMSREQUEST
DESCRIPTOR.message_types_by_name['ListPostMortemsResponse'] = _LISTPOSTMORTEMSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePostMortemRequest'] = _CREATEPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['CreatePostMortemResponse'] = _CREATEPOSTMORTEMRESPONSE
DESCRIPTOR.message_types_by_name['UpdatePostMortemRequest'] = _UPDATEPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['UpdatePostMortemResponse'] = _UPDATEPOSTMORTEMRESPONSE
DESCRIPTOR.message_types_by_name['GetPostMortemRequest'] = _GETPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['GetPostMortemResponse'] = _GETPOSTMORTEMRESPONSE
DESCRIPTOR.message_types_by_name['DeletePostMortemRequest'] = _DELETEPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['DeletePostMortemResponse'] = _DELETEPOSTMORTEMRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPostMortemsRequest = _reflection.GeneratedProtocolMessageType('ListPostMortemsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPOSTMORTEMSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPOSTMORTEMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest)
  })
_sym_db.RegisterMessage(ListPostMortemsRequest)
_sym_db.RegisterMessage(ListPostMortemsRequest.LabelsEntry)

ListPostMortemsResponse = _reflection.GeneratedProtocolMessageType('ListPostMortemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOSTMORTEMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse)
  })
_sym_db.RegisterMessage(ListPostMortemsResponse)

CreatePostMortemRequest = _reflection.GeneratedProtocolMessageType('CreatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest)
  })
_sym_db.RegisterMessage(CreatePostMortemRequest)

CreatePostMortemResponse = _reflection.GeneratedProtocolMessageType('CreatePostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemResponse)
  })
_sym_db.RegisterMessage(CreatePostMortemResponse)

UpdatePostMortemRequest = _reflection.GeneratedProtocolMessageType('UpdatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest)
  })
_sym_db.RegisterMessage(UpdatePostMortemRequest)

UpdatePostMortemResponse = _reflection.GeneratedProtocolMessageType('UpdatePostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemResponse)
  })
_sym_db.RegisterMessage(UpdatePostMortemResponse)

GetPostMortemRequest = _reflection.GeneratedProtocolMessageType('GetPostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest)
  })
_sym_db.RegisterMessage(GetPostMortemRequest)

GetPostMortemResponse = _reflection.GeneratedProtocolMessageType('GetPostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse)
  })
_sym_db.RegisterMessage(GetPostMortemResponse)

DeletePostMortemRequest = _reflection.GeneratedProtocolMessageType('DeletePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest)
  })
_sym_db.RegisterMessage(DeletePostMortemRequest)

DeletePostMortemResponse = _reflection.GeneratedProtocolMessageType('DeletePostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemResponse)
  })
_sym_db.RegisterMessage(DeletePostMortemResponse)


DESCRIPTOR._options = None
_LISTPOSTMORTEMSREQUEST_LABELSENTRY._options = None

_POSTMORTEMSERVICE = _descriptor.ServiceDescriptor(
  name='PostMortemService',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1073,
  serialized_end=2182,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPostMortems',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.ListPostMortems',
    index=0,
    containing_service=None,
    input_type=_LISTPOSTMORTEMSREQUEST,
    output_type=_LISTPOSTMORTEMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/postmortems',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePostMortem',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.CreatePostMortem',
    index=1,
    containing_service=None,
    input_type=_CREATEPOSTMORTEMREQUEST,
    output_type=_CREATEPOSTMORTEMRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/postmortems:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPostMortem',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.GetPostMortem',
    index=2,
    containing_service=None,
    input_type=_GETPOSTMORTEMREQUEST,
    output_type=_GETPOSTMORTEMRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/postmortems/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePostMortem',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.UpdatePostMortem',
    index=3,
    containing_service=None,
    input_type=_UPDATEPOSTMORTEMREQUEST,
    output_type=_UPDATEPOSTMORTEMRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/postmortems/{postmortem.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePostMortem',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.DeletePostMortem',
    index=4,
    containing_service=None,
    input_type=_DELETEPOSTMORTEMREQUEST,
    output_type=_DELETEPOSTMORTEMRESPONSE,
    serialized_options=b'\202\323\344\223\0026*4/api/v1alpha1/postmortems/{postmortem.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_POSTMORTEMSERVICE)

DESCRIPTOR.services_by_name['PostMortemService'] = _POSTMORTEMSERVICE

# @@protoc_insertion_point(module_scope)
